import json, os
import requests

CONFIG_FILE = "{0}/.okta_cmd".format(os.getenv("HOME"))
REQUIRED_LIST = ['url', 'token']

def get_config():
  with open(CONFIG_FILE) as f:
    data = json.load(f)
    check_config(data)
    return data

def set_config(data):
  with open(CONFIG_FILE, 'w+') as f:
    json.dump(data, f)

def check_config(data):
  for name in REQUIRED_LIST:
    if not data.get(name):
      raise Exception("Config File missing parameter: {0}, Please use the init command to initialize".format(name))

def request_session(session, url, method, **kwargs):
  result = getattr(session, method)(url, **kwargs)
  if result.status_code >= 400:
    raise requests.HTTPError(json.dumps(result.json()))
  return result



import click
from .okta import Okta
from .common import *

@click.group()
@click.pass_context
def main_cli(ctx):
  if ctx.invoked_subcommand != 'init':
    okta = Okta()
    config_data = get_config()
    okta.init(config_data['url'], config_data['token'])
    ctx.obj = okta
    
@main_cli.command()
@click.option('--url', required=True)
@click.option('--token', required=True)
@click.pass_obj
def init(ctx, url, token):
  set_config({'url': url, 'token': token})
  print('done.')

@main_cli.command()
@click.pass_obj
def auth(ctx):
  print('Steven Love Tina')

@main_cli.command()
@click.pass_obj
def user_list(okta):
  print(okta.user_list())

@main_cli.command()
@click.pass_obj
def group_list(okta):
  print(okta.group_list())

@main_cli.command()
@click.option('--name', required=True)
@click.pass_obj
def add_group(okta, name):
  print(okta.add_group(name))

@main_cli.command()
@click.option('--file', required=True)
@click.option('--group', required=True)
@click.pass_obj
def add_user_list_to_group(okta, file, group):
  okta.add_user_list_to_group(file, group)

@main_cli.command()
@click.option('--group', required=True)
@click.option('--othergroup', required=True)
@click.pass_obj
def copy_group_to_other(okta, group, othergroup):
  okta.copy_group_to_other(group, othergroup)



import os
from setuptools import setup, find_packages


path = os.path.abspath(os.path.dirname(__file__))

try:
  with open(os.path.join(path, 'README.md')) as f:
    long_description = f.read()
except Exception as e:
  long_description = "customize okta cli"

setup(
    name = "okta-cmd",
    version = "0.0.5",
    keywords = ("pip", "okta", "cli", "cmd", "steven"),
    description = "okta cli",
    long_description = long_description,
    license = "MIT Licence",

    url = "https://github.com/stevenQiang/okta-cmd",
    author = "steven",
    author_email = "qianggao7@gmail.com",

    packages = find_packages(),
    include_package_data = True,
    install_requires = ["requests", "click"],
    platforms = "any",

    scripts = [],
    entry_points = {
        'console_scripts': [
            'okta-cmd=oktacmd:main_cli'
        ]
    }
)
